@@ -1,9 +1,7 @@
-import webbrowser
-
 import click
 
+from sym.flow.cli.helpers.api import SymAPI
 from sym.flow.cli.helpers.global_options import GlobalOptions
-from sym.flow.cli.helpers.sym_api_client import SymAPIClient
 
 
 @click.command(name="delete", short_help="Remove the Sym App from Slack")
@@ -30,5 +28,5 @@ def slack_delete(options: GlobalOptions, workspace_id: str) -> None:
 
 
 def slack_uninstall(api_url: str, workspace_id: str):
-    api_client = SymAPIClient(url=api_url)
-    api_client.uninstall_slack(workspace_id)
+    api = SymAPI(url=api_url)
+    api.uninstall_slack(workspace_id)
