@@ -2,8 +2,8 @@ import webbrowser
 
 import click
 
+from sym.flow.cli.helpers.api import SymAPI
 from sym.flow.cli.helpers.global_options import GlobalOptions
-from sym.flow.cli.helpers.sym_api_client import SymAPIClient
 
 
 @click.command(name="new", short_help="Add the Sym App to Slack")
@@ -27,7 +27,5 @@ def slack_new(options: GlobalOptions) -> None:
         webbrowser.open(url)
 
 
-def get_magic_url(api_url: str):
-    api_client = SymAPIClient(url=api_url)
-    url, _ = api_client.get_slack_install_url()
-    return url
+def get_magic_url(api_url):
+    return SymAPI(url=api_url).get_slack_install_url()
