@@ -1,12 +1,13 @@
 import click
-from sym.cli.decorators import setup_segment, setup_sentry
-from sym.cli.helpers.sym_group import SymGroup
-from sym.cli.helpers.updater import SymUpdater
+from sym.shared.cli.decorators import setup_segment, setup_sentry
+from sym.shared.cli.helpers.sym_group import SymGroup
+from sym.shared.cli.helpers.updater import SymUpdater
 
+from sym.flow.cli.commands.config import config_commands
 from sym.flow.cli.commands.connectors import connectors_commands
 from sym.flow.cli.commands.debug import debug_commands
 from sym.flow.cli.commands.integrations import integrations_commands
-from sym.flow.cli.commands.login import login
+from sym.flow.cli.commands.login import login, logout
 from sym.flow.cli.commands.status import status
 from sym.flow.cli.commands.update import update
 from sym.flow.cli.commands.users import users_commands
@@ -52,8 +53,8 @@ def symflow(options: GlobalOptions, auth_url: str, api_url: str, debug: bool) ->
     """
 
     options.debug = debug
-    options.api_url = api_url
-    options.auth_url = auth_url
+    options.set_api_url(api_url)
+    options.set_auth_url(auth_url)
     options.dprint(auth_url=auth_url, api_url=api_url)
 
     SymUpdater(debug=debug).auto_update()
@@ -62,8 +63,10 @@ def symflow(options: GlobalOptions, auth_url: str, api_url: str, debug: bool) ->
 symflow.add_command(version)
 symflow.add_command(update)
 symflow.add_command(login)
+symflow.add_command(logout)
 symflow.add_command(status)
 symflow.add_command(connectors_commands)
 symflow.add_command(integrations_commands)
 symflow.add_command(users_commands)
 symflow.add_command(debug_commands)
+symflow.add_command(config_commands)
