@@ -1,5 +1,5 @@
 import click
-from sym.cli.helpers.updater import SymUpdater
+from sym.shared.cli.helpers.updater import SymUpdater
 
 from sym.flow.cli.helpers.global_options import GlobalOptions
 
