@@ -1,15 +1,7 @@
-from typing import Dict, List
-
 import click
 
+from sym.flow.cli.helpers.api import SymAPI
 from sym.flow.cli.helpers.global_options import GlobalOptions
-from sym.flow.cli.helpers.sym_api_client import SymAPIClient
-from sym.flow.cli.helpers.sym_api_service import SymAPIService
-
-
-def patch_user_data(api_url: str, csv_data: str) -> List[Dict[str, str]]:
-    api_service = SymAPIService(api_client=SymAPIClient(url=api_url))
-    return api_service.patch_user_table_data(csv_data)
 
 
 @click.command(name="update", short_help="Upload a CSV with new User Identities")
@@ -19,6 +11,13 @@ def patch_user_data(api_url: str, csv_data: str) -> List[Dict[str, str]]:
     type=click.Path(exists=True, readable=True, file_okay=True, dir_okay=False),
 )
 def users_update(options: GlobalOptions, csv_path: str) -> None:
+    """Upload data from a CSV to update Sym Users in your Organization. This can be used to create or modify Sym Users and identities such as AWS SSO IDs.
+
+    \b
+    Example:
+        `symflow users update my-users.csv`
+    """
+
     with open(csv_path) as f:
-        result = patch_user_data(options.api_url, f.read())
+        result = SymAPI(url=options.api_url).update_users(f.read())
     click.secho(f"Successfully updated {len(result)} Users!")
