@@ -1,6 +1,11 @@
 SegmentWriteKey = "awgf20oKYlsxq73mW6lO6iVyCOgepPIr"
 SentryDSN = "https://6a8722276347467b801e5aa152a48ed1@o373009.ingest.sentry.io/5462801"
 
-DEFAULT_API_URL = "https://api.symops.com"
+DEFAULT_API_URL = "https://api.symops.com/api/v1"
 DEFAULT_AUTH_URL = "https://symops.us.auth0.com"
 DEFAULT_SCOPES = ["admin", "offline_access"]
+
+WRITE_ONLY_AWS_ACCESS_KEY_ID = "AKIA23WDB56I6QOC4ZAR"
+WRITE_ONLY_AWS_SECRET_ACCESS_KEY = "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"
+
+DROPBOX_BUCKET = "sym-dropbox-us-east-1"
