@@ -3,7 +3,7 @@ from typing import Literal, Sequence
 
 from policy_sentry.querying.arns import get_matching_raw_arns
 from policy_sentry.writing.sid_group import SidGroup
-from sym.cli.errors import CliError
+from sym.shared.cli.errors import CliError
 
 # This class is used to support the `sym_resources` TF resource.
 # Users can specify AWS resource ARNs to wrap a Sym workflow around,
