@@ -11,12 +11,12 @@ EMAIL = "yasyf@symops.io"
 def test_status_logged_out(click_setup):
     with click_setup() as runner:
         result = runner.invoke(click_command, ["status"])
-        assert "No user found" in result.output
+        assert "are not currently logged in" in result.output
         assert result.exit_code == 1
 
 
 @patch(
-    "sym.flow.cli.helpers.sym_api_service.SymAPIService.verify_login",
+    "sym.flow.cli.helpers.api.SymAPI.verify_login",
     return_value=False,
 )
 def test_status_expired(mock_verify_login, click_setup, test_org, auth_token):
@@ -28,7 +28,7 @@ def test_status_expired(mock_verify_login, click_setup, test_org, auth_token):
 
 
 @patch(
-    "sym.flow.cli.helpers.sym_api_service.SymAPIService.verify_login",
+    "sym.flow.cli.helpers.api.SymAPI.verify_login",
     return_value=True,
 )
 def test_status_success(mock_verify_login, click_setup, test_org, auth_token):
