@@ -4,8 +4,8 @@ from typing import Optional, Union
 
 import pytest
 from requests import Response
-from sym.cli.helpers.config import init
-from sym.cli.tests.conftest import capture_command, wrapped_cli_runner  # noqa
+from sym.shared.cli.helpers.config import init
+from sym.shared.cli.tests.conftest import capture_command, wrapped_cli_runner  # noqa
 
 from sym.flow.cli.models import AuthToken, Organization
 from sym.flow.cli.tests.helpers.sandbox import Sandbox
