@@ -7,8 +7,8 @@ import pkce
 import pytest
 import requests
 from requests import Response
+from sym.shared.cli.errors import CliError
 
-from sym.cli.errors import CliError
 from sym.flow.cli.errors import InvalidTokenError
 from sym.flow.cli.helpers.login.login_flow import BrowserRedirectFlow, LoginError
 
@@ -48,7 +48,7 @@ def test_get_auth_code(mocker, browser_redirect_flow, global_options, test_org):
     assert code == "1234XYZ"
     assert verifier == "test-verifier"
     webbrowser.open.assert_called_once_with(
-        f"https://auth.com/authorize?response_type=code&client_id={test_org['client_id']}&code_challenge_method=S256&code_challenge=test-challenge&redirect_uri=http://localhost:11001/callback&scope=admin offline_access&audience=https://api.com&state=foo"
+        f"https://auth.com/authorize?response_type=code&client_id={test_org['client_id']}&code_challenge_method=S256&code_challenge=test-challenge&redirect_uri=http://localhost:11001/callback&scope=admin offline_access&audience=https://api.symops.com&state=foo&prompt=login"
     )
 
 
@@ -71,7 +71,7 @@ def test_wait_for_code_missing_code(wait_for_code_tester):
         assert r.status_code == 401
         assert "Missing code in query" in r.text
 
-    wait_for_code_tester(expected_state="foo", expected_code="", do_test=do_test)
+    wait_for_code_tester(expected_state="foo", expected_code=None, do_test=do_test)
 
 
 def test_wait_for_code_missing_state(wait_for_code_tester):
@@ -80,9 +80,7 @@ def test_wait_for_code_missing_state(wait_for_code_tester):
         assert r.status_code == 401
         assert "Missing state in query" in r.text
 
-    wait_for_code_tester(
-        expected_state="", expected_code="test_wait_for_code", do_test=do_test
-    )
+    wait_for_code_tester(expected_state="", expected_code=None, do_test=do_test)
 
 
 def test_wait_for_code_invalid_state(wait_for_code_tester):
@@ -93,9 +91,7 @@ def test_wait_for_code_invalid_state(wait_for_code_tester):
         assert r.status_code == 401
         assert "Invalid state" in r.text
 
-    wait_for_code_tester(
-        expected_state="foo", expected_code="test_wait_for_code", do_test=do_test
-    )
+    wait_for_code_tester(expected_state="foo", expected_code=None, do_test=do_test)
 
 
 def test_get_token_from_code_ok(mocker, browser_redirect_flow, global_options, test_org):
